@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,6 +12,4 @@ ClawsMailAddressBook::ClawsMailAddressBook(const QDir &dir)
 {
 }
 
-ClawsMailAddressBook::~ClawsMailAddressBook()
-{
-}
+ClawsMailAddressBook::~ClawsMailAddressBook() = default;
