@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ SylpheedAddressBook::SylpheedAddressBook(const QDir &dir)
 {
 }
 
-SylpheedAddressBook::~SylpheedAddressBook()
-{
-}
+SylpheedAddressBook::~SylpheedAddressBook() = default;
 
 void SylpheedAddressBook::importAddressBook()
 {
