@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,9 +24,7 @@ SylpheedImportData::SylpheedImportData(QObject *parent, const QList<QVariant> &)
     mPath = MailImporter::FilterSylpheed::defaultSettingsPath();
 }
 
-SylpheedImportData::~SylpheedImportData()
-{
-}
+SylpheedImportData::~SylpheedImportData() = default;
 
 bool SylpheedImportData::foundMailer() const
 {
